@@ -1,11 +1,11 @@
 <?php
-/*
- * $Horde: turba/data.php,v 1.12.2.10 2002/05/27 17:05:20 jan Exp $
+/**
+ * $Horde: turba/data.php,v 1.12.2.21 2005/01/03 11:26:03 jan Exp $
  *
- * Copyright 2001-2002 Jan Schneider <jan@horde.org>
+ * Copyright 2001-2005 Jan Schneider <jan@horde.org>
  *
- * See the enclosed file COPYING for license information (GPL).  If you
- * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
+ * See the enclosed file COPYING for license information (ASL).  If you
+ * did not receive this file, see http://www.horde.org/licenses/asl.php.
  */
 
 define('TURBA_BASE', dirname(__FILE__));
@@ -20,7 +20,7 @@ if (!$conf['menu']['import_export']) {
 }
 
 $error = false;
-$actionID = Horde::getFormData('actionID', NO_ACTION);
+$actionID = Horde::getFormData('actionID');
 
 if ($actionID == HORDE_IMPORT) {
 
@@ -133,10 +133,13 @@ if ($actionID == HORDE_IMPORT) {
                 $import_type = Horde::getFormData('import_type');
                 switch ($import_type) {
                 case IMPORT_CSV:
-                    $type = "CSV";
+                    $type = 'CSV';
+                    break;
+                case IMPORT_TSV:
+                    $type = 'TSV';
                     break;
                 case IMPORT_OUTLOOK:
-                    $type = "Outlook";
+                    $type = 'Outlook';
                     break;
                 }
                 Horde::raiseMessage(sprintf(_("%s file successfully imported"), $type), HORDE_SUCCESS);
@@ -146,15 +149,15 @@ if ($actionID == HORDE_IMPORT) {
 
     } else {
 
-        if (!isset($HTTP_POST_FILES['import_file']['size']) ||
-            !isset($HTTP_POST_FILES['import_file']['tmp_name'])) {
+        if (!isset($_FILES['import_file']['size']) ||
+            !isset($_FILES['import_file']['tmp_name'])) {
             Horde::raiseMessage(_("There was a problem with the file upload. The file may have been larger than the maximum allowed size."), HORDE_ERROR);
             $error = true;
-        } elseif (!is_uploaded_file($HTTP_POST_FILES['import_file']['tmp_name'])) {
+        } elseif (!is_uploaded_file($_FILES['import_file']['tmp_name'])) {
             Horde::raiseMessage(_("Illegal or malformed form data."), HORDE_ERROR);
             $error = true;
-        } elseif ($HTTP_POST_FILES['import_file']['size'] > 0) {
-            _fileCleanup($HTTP_POST_FILES['import_file']['tmp_name']);
+        } elseif ($_FILES['import_file']['size'] > 0) {
+            _fileCleanup($_FILES['import_file']['tmp_name']);
 
             $header = null;
             switch ($importID) {
@@ -167,7 +170,35 @@ if ($actionID == HORDE_IMPORT) {
                 if (!isset($header)) {
                     $header = Horde::getFormData('header');
                 }
-                $importData = $csv->importFile($HTTP_POST_FILES['import_file']['tmp_name'], $header, ',');
+                $importData = $csv->importFile($_FILES['import_file']['tmp_name'], $header, ',');
+
+                if (!isset($importData) || !is_array($importData)) {
+                    Horde::raiseMessage(_("There was an error importing the uploaded file"), HORDE_ERROR);
+                    $error = true;
+                } else {
+                    $dest = Horde::getFormData('dest');
+                    include_once HORDE_BASE . '/lib/SessionCache.php';
+                    $cache = new SessionCache();
+                    $cacheID = $cache->putObject(array($importData, $dest));
+                    $actionUrl = Horde::applicationUrl('data.php');
+
+                    $appFields = array();
+                    reset($cfgSources[$dest]['map']);
+                    while (list($key, ) = each($cfgSources[$dest]['map'])) {
+                        if (substr($key, 0, 2) != '__') {
+                            $appFields[$key] = $attributes[$key]['desc'];
+                        }
+                    }
+                }
+
+                break;
+
+            case IMPORT_TSV:
+                $tsv = new Data_tsv();
+                if (!isset($header)) {
+                    $header = Horde::getFormData('header');
+                }
+                $importData = $tsv->importFile($_FILES['import_file']['tmp_name'], $header, "\t");
 
                 if (!isset($importData) || !is_array($importData)) {
                     Horde::raiseMessage(_("There was an error importing the uploaded file"), HORDE_ERROR);
@@ -192,7 +223,7 @@ if ($actionID == HORDE_IMPORT) {
 
             case IMPORT_VCARD:
                 $vcf = new Data_rfc2425();
-                $data = $vcf->importFile($HTTP_POST_FILES['import_file']['tmp_name']);
+                $data = $vcf->importFile($_FILES['import_file']['tmp_name']);
                 $dest = Horde::getFormData('dest');
                 $driver = &Turba_Source::singleton($dest, $cfgSources[$dest]);
                 if (PEAR::isError($driver)) {
@@ -201,7 +232,8 @@ if ($actionID == HORDE_IMPORT) {
                 } else {
                     $dest = $cfgSources[$dest]['map'];
                     foreach ($data as $object) {
-                        if ($object['type'] == 'VCARD') {
+                        if (strtoupper($object['type']) == 'VCARD') {
+                            $vcf->version = isset($object['version']) ? $object['version'] : null;
                             $hash = array();
                             foreach ($object['params'] as $item) {
 
@@ -242,7 +274,7 @@ if ($actionID == HORDE_IMPORT) {
 
                                 case 'EMAIL':
                                     if (isset($item['params']['PREF']) || !isset($hash['email'])) {
-                                        $hash['email'] = $vcf->read($item);
+                                        $hash['email'] = Turba::getBareEmail($vcf->read($item));
                                     }
                                     break;
 
@@ -281,6 +313,114 @@ if ($actionID == HORDE_IMPORT) {
 
                 break;
 
+            case IMPORT_MULBERRY:
+                $mulberry = new Data_tsv();
+                $importData = $mulberry->importFile($_FILES['import_file']['tmp_name']);
+                $dest = Horde::getFormData('dest');
+                $driver = &Turba_Source::singleton($dest, $cfgSources[$dest]);
+                if (!isset($importData) || !is_array($importData)) {
+                    Horde::raiseMessage(_("There was an error importing the uploaded file"), HORDE_ERROR);
+                    $error = true;
+                } elseif (PEAR::isError($driver)) {
+                    Horde::raiseMessage(_("Failed to connect to the specified directory."), HORDE_ERROR);
+                    $error = true;
+                } else {
+                    include_once HORDE_BASE . '/lib/SessionCache.php';
+                    $cache = new SessionCache();
+                    $cacheID = $cache->putObject(array($importData, $dest));
+                    if (!isset($cacheID) || !(list($importData, $dest) = $cache->getObject($cacheID))) {
+                        Horde::raiseMessage(_("The data got lost."), HORDE_ERROR);
+                        $error = true;
+                    } else {
+                        $import_type = Horde::getFormData('import_type');
+                        $appKeys = array('alias', 'name', 'email', 'company', 'workAddress', 'workPhone', 'homePhone', 'fax', 'notes');
+                        $dataKeys = array(0, 1, 2, 3, 4, 5, 6, 7, 9);
+                        $map = array();
+                        foreach ($appKeys as $key => $app) {
+                            $map[$app] = $dataKeys[$key];
+                        }
+                        foreach ($importData as $row) {
+                            $hash = array();
+                            reset($cfgSources[$dest]['map']);
+                            if (preg_match("/^Grp:/", $row[0])) {
+                                continue;
+                            }
+                            $row[1] = preg_replace('/^([^,"]+),\s*(.*)$/', '$2 $1', $row[1]);
+                            while (list($key,) = each($cfgSources[$dest]['map'])) {
+                                if (isset($map[$key]) && !empty($row[$map[$key]])) {
+                                    $hash[$key] = stripslashes(preg_replace('/\\\\r/', "\n", $row[$map[$key]]));
+                                }
+                            }
+                            $hash['__owner'] = Auth::getAuth();
+                            if (!$driver->addObject($hash)) {
+                                $error = true;
+                            }
+                        }
+                    }
+                }
+
+                if ($error) {
+                    Horde::raiseMessage(_("There was an error importing the data."), HORDE_ERROR);
+                } else {
+                    Horde::raiseMessage(_("Mulberry addressbook sucessfully imported"), HORDE_SUCCESS);
+                }
+
+            break;
+
+            case IMPORT_PINE:
+                $pine = new Data_tsv();
+                $importData = $pine->importFile($_FILES['import_file']['tmp_name']);
+                $dest = Horde::getFormData('dest');
+                $driver = &Turba_Source::singleton($dest, $cfgSources[$dest]);
+                if (!isset($importData) || !is_array($importData)) {
+                    Horde::raiseMessage(_("There was an error importing the uploaded file"), HORDE_ERROR);
+                    $error = true;
+                } elseif (PEAR::isError($driver)) {
+                    Horde::raiseMessage(_("Failed to connect to the specified directory."), HORDE_ERROR);
+                    $error = true;
+                } else {
+                    include_once HORDE_BASE . '/lib/SessionCache.php';
+                    $cache = new SessionCache();
+                    $cacheID = $cache->putObject(array($importData, $dest));
+                    if (!isset($cacheID) || !(list($importData, $dest) = $cache->getObject($cacheID))) {
+                        Horde::raiseMessage(_("The data got lost."), HORDE_ERROR);
+                        $error = true;
+                    } else {
+                        $import_type = Horde::getFormData('import_type');
+                        $appKeys = array('alias', 'name', 'email', 'notes');
+                        $dataKeys = array(0, 1, 2, 4);
+                        $map = array();
+                        foreach ($appKeys as $key => $app) {
+                            $map[$app] = $dataKeys[$key];
+                        }
+                        foreach ($importData as $row) {
+                            $hash = array();
+                            reset($cfgSources[$dest]['map']);
+                            if (count($row) < 3 || preg_match("/^#DELETED/", $row[0]) || preg_match("/[()]/", $row[2])) {
+                                continue;
+                            }
+                            $row[1] = preg_replace('/^([^,"]+),\s*(.*)$/', '$2 $1', $row[1]);
+                            while (list($key, ) = each($cfgSources[$dest]['map'])) {
+                                if (isset($map[$key]) && !empty($row[$map[$key]])) {
+                                    $hash[$key] = $row[$map[$key]];
+                                }
+                            }
+                            $hash['__owner'] = Auth::getAuth();
+                            if (!$driver->addObject($hash)) {
+                                $error = true;
+                            }
+                        }
+                    }
+                }
+
+                if ($error) {
+                    Horde::raiseMessage(_("There was an error importing the data."), HORDE_ERROR);
+                } else {
+                    Horde::raiseMessage(_("Pine addressbook sucessfully imported"), HORDE_SUCCESS);
+                }
+
+            break;
+
             }
 
         } else {
@@ -329,6 +469,42 @@ if ($actionID == HORDE_IMPORT) {
         }
         break;
 
+
+    case EXPORT_TSV:
+        $source = Horde::getFormData('source');
+        if (!isset($source) && isset($cfgSources) && is_array($cfgSources) && count($cfgSources) > 0) {
+            reset($cfgSources);
+            $source = key($cfgSources);
+        }
+
+        $driver = &Turba_Source::singleton($source, $cfgSources[$source]);
+        if (PEAR::isError($driver)) {
+            Horde::raiseMessage(_("Failed to connect to the specified directory."), HORDE_ERROR);
+            $error = true;
+        } else {
+            if (get_class($addresses = $driver->search(array())) != 'turba_list') {
+                Horde::raiseMessage(sprintf(_("Failed to search the directory: %s"), $driver->error()), HORDE_ERROR);
+                $error = true;
+            } else {
+                $data = array();
+                while ($ob = $addresses->next()) {
+                    $tmp = $ob->getAttributes();
+                    $row = array();
+                    foreach ($tmp as $key => $attribute) {
+                        if (substr($key, 0, 2) != '__') {
+                            $row[$key] = $attribute;
+                        }
+                    }
+                    $data[] = $row;
+                }
+
+                $tsv = new Data_tsv();
+                $tsv->exportFile('turba.tsv', $data, true);
+                exit;
+            }
+        }
+        break;
+
     }
 }
 
@@ -338,7 +514,7 @@ require TURBA_TEMPLATES . '/common-header.inc';
 require TURBA_BASE . '/menu.php';
 require TURBA_BASE . '/status.php';
 
-if ($actionID == NO_ACTION || $error) {
+if (is_null($actionID) || $error) {
     /* Build the directory sources select widget. */
     $source_options = '';
     foreach ($cfgSources as $key => $entry) {
@@ -368,6 +544,7 @@ if ($actionID == NO_ACTION || $error) {
 
     case IMPORT_OUTLOOK:
     case IMPORT_CSV:
+    case IMPORT_TSV:
         include $registry->getParam('templates', 'horde') . '/data/csvmap.inc';
         break;
 
@@ -383,5 +560,3 @@ if ($actionID == NO_ACTION || $error) {
 
 $registry->shutdown();
 require TURBA_TEMPLATES . '/common-footer.inc';
-
-?>
