@@ -1,13 +1,11 @@
 <?php
 /*
- * $Horde: turba/displayobject.php,v 1.9.2.6 2002/03/19 01:59:25 chuck Exp $
+ * $Horde: turba/displayobject.php,v 1.9.2.12 2005/01/03 11:26:04 jan Exp $
  *
- * Turba: Copyright 2000-2002 Charles J. Hagenbuch <chuck@horde.org>
+ * Turba: Copyright 2000-2005 Charles J. Hagenbuch <chuck@horde.org>
  *
- * You should have received a copy of the GNU Public
- * License along with this package; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * See the enclosed file COPYING for license information (ASL).  If you
+ * did not receive this file, see http://www.horde.org/licenses/asl.php.
  */
 
 define('TURBA_BASE', dirname(__FILE__));
@@ -16,6 +14,11 @@ require_once TURBA_BASE . '/lib/Source.php';
 require_once TURBA_BASE . '/lib/ObjectView.php';
 
 $source = Horde::getFormData('source');
+if (empty($source)) {
+    header('Location: ' . Horde::applicationUrl($prefs->getValue('initial_page'), true));
+    exit;
+}
+
 $driver = &Turba_Source::singleton($source, $cfgSources[$source]);
 
 $object = $driver->getObject(Horde::getFormData('key'));
@@ -36,5 +39,3 @@ if (isset($view) && is_object($view)) {
 
 require TURBA_TEMPLATES . '/common-footer.inc';
 $registry->shutdown();
-
-?>
